pub struct NautClient { /* private fields */ }Trait Implementations
Sourceimpl Default for NautClient
impl Default for NautClient
Sourcefn default() -> NautClient
fn default() -> NautClient
Returns the “default value” for a type. Read more
Sourceimpl SocketPlugin<'_, NautClient> for LoggingPlugin
impl SocketPlugin<'_, NautClient> for LoggingPlugin
fn register(&self, socket: &mut NautSocket<'_, NautClient>)
Sourceimpl<'socket> SocketType<'socket> for NautClient
impl<'socket> SocketType<'socket> for NautClient
Sourcefn update_current_send_seq_num_for_event(
&mut self,
_addr: &SocketAddr,
event: &str,
) -> Option<SequenceNumber>
fn update_current_send_seq_num_for_event( &mut self, _addr: &SocketAddr, event: &str, ) -> Option<SequenceNumber>
Updates the current sequence number for that specific event and should be
handled on a per client basis
Sourcefn last_recv_seq_num_for_event(
&'socket mut self,
_addr: &SocketAddr,
event: &str,
) -> Option<&'socket mut SequenceNumber>
fn last_recv_seq_num_for_event( &'socket mut self, _addr: &SocketAddr, event: &str, ) -> Option<&'socket mut SequenceNumber>
Returns a mutable reference to the last received sequence number, it should be changed to
the newest sequence number if the last received sequence number is lower