PacketDelivery

Enum PacketDelivery 

#[repr(u16)]
pub enum PacketDelivery { Unreliable = 0, UnreliableSequenced = 1, Reliable = 2, ReliableSequenced = 3, AckDelivery(SocketDelivery), DetailRequest(SocketDelivery), }
Describes how a packet will reach its target

Variants



Unreliable = 0

A packet which has no guarantee of reaching its target, and if it doesn’t it will be forgotten



UnreliableSequenced = 1

A packet which has no guarantee of reaching its target, and will be discarded if not the latest packet in sequence or will be forgotten if it does not reach the target



Reliable = 2

A packet which will require an acknowledgement. If the package receives no ack it will be resent to the target



ReliableSequenced = 3

A packet which will require an acknowledgement. If the package receives no ack it will be resent to the target, however the packet may be discared if not the latest packet



AckDelivery(SocketDelivery)

The packet delivery type for an acknowledgement packet



DetailRequest(SocketDelivery)

In place packet delivery type to request the details of the server without establishing a connection

Implementations

Source

impl PacketDelivery

pub fn is_reliable(&self) -> bool

Is a reliable delivery type

pub fn is_unreliable(&self) -> bool

Is an unreliable delivery type

pub fn is_sequenced(&self) -> bool

Is a sequenced delivery type