pub trait SocketPlugin<'socket, S: SocketType<'socket>> {
// Required method
fn register(&self, socket: &mut NautSocket<'socket, S>);
}Expand description
Allows you to isolate specific functionality into different plugins
pub trait SocketPlugin<'socket, S: SocketType<'socket>> {
// Required method
fn register(&self, socket: &mut NautSocket<'socket, S>);
}Allows you to isolate specific functionality into different plugins