pub struct ServerConfig {
pub max_connections: u8,
pub idle_connection_time: Duration,
}Expand description
The config of how the server should be structured
Fields
max_connections: u8The max amount of connections the server will process
idle_connection_time: DurationHow long it takes for the server to free an idling client