pub enum ServerEvent {
OnClientConnected(ConnectionId),
OnClientTimeout(ConnectionId),
OnClientDisconnected(ConnectionId),
}Variants
OnClientConnected(ConnectionId)
Pushed to the server event queue when a client connects
OnClientTimeout(ConnectionId)
Pushed to the server event queue when a client times out
OnClientDisconnected(ConnectionId)
Pushes to the server event queue when a client is disconnected